@@ -4,8 +4,7 @@ import java.io.IOException;
 import java.net.DatagramPacket;
 import java.net.DatagramSocket;
 import java.net.InetAddress;
-import java.net.SocketException;
-import java.net.UnknownHostException;
+import java.net.MulticastSocket;
 import com.openexchange.configuration.ConfigurationException;
 import com.openexchange.push.PushException;
 
@@ -17,20 +16,25 @@ import com.openexchange.push.PushException;
  */
 public class MailNotifyPushUdpSocketListener implements Runnable {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailNotifyPushUdpSocketListener.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(MailNotifyPushUdpSocketListener.class));
 
     private static final int MAX_UDP_PACKET_SIZE = 4+64+1;
     
-    private static DatagramSocket datagramSocket;
+    private static DatagramSocket datagramSocket = null;
     
     private final String imapLoginDelimiter;
     
-    public MailNotifyPushUdpSocketListener(final String udpListenHost, final int udpListenPort, final String imapLoginDelimiter) throws UnknownHostException, SocketException, ConfigurationException {
+    public MailNotifyPushUdpSocketListener(final String udpListenHost, final int udpListenPort, final String imapLoginDelimiter, final boolean multicast) throws ConfigurationException, IOException {
         InetAddress senderAddress = InetAddress.getByName(udpListenHost);
 
         this.imapLoginDelimiter = imapLoginDelimiter;
         if (senderAddress != null) {
-            datagramSocket = new DatagramSocket(udpListenPort, senderAddress);
+            if (multicast) {
+                datagramSocket = new MulticastSocket(udpListenPort);
+                ((MulticastSocket)datagramSocket).joinGroup(senderAddress);
+            } else {
+                datagramSocket = new DatagramSocket(udpListenPort, senderAddress);
+            }
         } else {
             throw new ConfigurationException(ConfigurationException.Code.INVALID_CONFIGURATION, "Can't get internet addres to given hostname " + udpListenHost);
         }
@@ -74,7 +78,13 @@ public class MailNotifyPushUdpSocketListener implements Runnable {
         String packetDataString = new String(datagramPacket.getData());
         // user name at position 3, see above
         packetDataString = packetDataString.split("\0")[3];
-        packetDataString = packetDataString.substring(0, packetDataString.indexOf(imapLoginDelimiter));
+        if (null != imapLoginDelimiter) {
+        	final int idx;
+        	idx = packetDataString.indexOf(imapLoginDelimiter);
+        	if (idx != -1) {
+        		packetDataString = packetDataString.substring(0, idx);
+        	}
+        }
         LOG.debug("Username=" + packetDataString);
         if (null != packetDataString && packetDataString.length() > 0) {
             return packetDataString;
