@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,8 +49,7 @@
 
 package com.openexchange.push.mail.notify.osgi;
 
-import java.net.SocketException;
-import java.net.UnknownHostException;
+import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.concurrent.Future;
@@ -82,7 +81,9 @@ public final class PushActivator extends DeferredActivator {
 
     private static final String CRLF = "\r\n";
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(PushActivator.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(PushActivator.class));
+    
+    private static final String PROP_UDP_LISTEN_MULTICAST = "com.openexchange.push.mail.notify.udp_listen_multicast";
     
     private static final String PROP_UDP_LISTEN_HOST = "com.openexchange.push.mail.notify.udp_listen_host";
 
@@ -90,14 +91,24 @@ public final class PushActivator extends DeferredActivator {
     
     private static final String PROP_IMAP_LOGIN_DELIMITER = "com.openexchange.push.mail.notify.imap_login_delimiter";
 
+    private static final String PROP_USE_OX_LOGIN = "com.openexchange.push.mail.notify.use_ox_login";
+
+    private static final String PROP_USE_EMAIL_ADDRESS = "com.openexchange.push.mail.notify.use_full_email_address";
+
     private List<ServiceRegistration> serviceRegistrations;
 
+    private boolean multicast;
+
     private String udpListenHost;
 
     private String imapLoginDelimiter;
 
     private int udpListenPort;
 
+    private boolean useOXLogin;
+
+    private boolean useEmailAddress;
+
     private Future<Object> udpThread;
 
     /**
@@ -150,7 +161,7 @@ public final class PushActivator extends DeferredActivator {
              * Register push manager
              */
             serviceRegistrations = new ArrayList<ServiceRegistration>(3);
-            serviceRegistrations.add(context.registerService(PushManagerService.class.getName(), new MailNotifyPushManagerService(), null));
+            serviceRegistrations.add(context.registerService(PushManagerService.class.getName(), new MailNotifyPushManagerService(useOXLogin, useEmailAddress), null));
             serviceRegistrations.add(context.registerService(
                 MailAccountDeleteListener.class.getName(),
                 new MailNotifyPushMailAccountDeleteListener(),
@@ -199,13 +210,23 @@ public final class PushActivator extends DeferredActivator {
          * Read configuration
          */
         final ConfigurationService configurationService = getService(ConfigurationService.class);
-        String tmp = configurationService.getProperty(PROP_UDP_LISTEN_HOST);
+        String tmp = configurationService.getProperty(PROP_UDP_LISTEN_MULTICAST);
+        multicast = false;
+        if (null != tmp) {
+            if (tmp.trim().equals("true")) {
+                sb.append("\t" + PROP_UDP_LISTEN_MULTICAST + ": true" + CRLF);
+                multicast = true;
+            }
+        }
+
+        tmp = configurationService.getProperty(PROP_UDP_LISTEN_HOST);
         if (null != tmp) {
             udpListenHost = tmp.trim();
             sb.append("\t" + PROP_UDP_LISTEN_HOST + ": " + udpListenHost + CRLF);
         } else {
             throw new ConfigurationException(ConfigurationException.Code.PROPERTY_MISSING, PROP_UDP_LISTEN_HOST);
         }
+
         tmp = configurationService.getProperty(PROP_IMAP_LOGIN_DELIMITER);
         if (null != tmp) {
             imapLoginDelimiter = tmp.trim();
@@ -214,6 +235,7 @@ public final class PushActivator extends DeferredActivator {
             imapLoginDelimiter = null;
             sb.append("\t" + PROP_IMAP_LOGIN_DELIMITER + ": not set" + CRLF);
         }
+
         tmp = configurationService.getProperty(PROP_UDP_LISTEN_PORT);
         if (null != tmp) {
             try {
@@ -225,12 +247,31 @@ public final class PushActivator extends DeferredActivator {
         } else {
             throw new ConfigurationException(ConfigurationException.Code.PROPERTY_MISSING, PROP_UDP_LISTEN_PORT);
         }
+
+        tmp = configurationService.getProperty(PROP_USE_OX_LOGIN);
+        useOXLogin = false;
+        if (null != tmp) {
+            if (tmp.trim().equals("true")) {
+                sb.append("\t" + PROP_USE_OX_LOGIN + ": true" + CRLF);
+                useOXLogin = true;
+            }
+        }
+
+        tmp = configurationService.getProperty(PROP_USE_EMAIL_ADDRESS);
+        useEmailAddress = false;
+        if (null != tmp) {
+            if (tmp.trim().equals("true")) {
+                sb.append("\t" + PROP_USE_EMAIL_ADDRESS + ": true" + CRLF);
+                useEmailAddress = true;
+            }
+        }
+
         LOG.info(sb);
     }
 
-    private void startUdpListener() throws UnknownHostException, SocketException, ConfigurationException {
-        final ThreadPoolService threadPoolService = getService(ThreadPoolService.class);
-        udpThread = threadPoolService.submit(ThreadPools.task(new MailNotifyPushUdpSocketListener(udpListenHost, udpListenPort, imapLoginDelimiter)));
+    private void startUdpListener() throws ConfigurationException, IOException {
+        final ThreadPoolService threadPoolService = ThreadPools.getThreadPool();
+        udpThread = threadPoolService.submit(ThreadPools.task(new MailNotifyPushUdpSocketListener(udpListenHost, udpListenPort, imapLoginDelimiter, multicast)));
     }
 
     private void stopUdpListener() {
